"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerCheckMurderEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player is attempting to murder another player, and is requesting
 * the host to verify the attempt and actually murder the player. Only admitted
 * if the client is the host.
 *
 * This event is useful if you want to prevent a murder from actually happening,
 * before it happens. Therefore this event doesn't guarantee that the victim is
 * actually dead, see {@link PlayerMurderEvent} to listen for that.
 */
class PlayerCheckMurderEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The other player that the player is attempting to murder.
     */
    victim, 
    /**
     * Whether or not this murder would normally be considered valid and thus
     * the player be murdered.
     */
    isValid) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.victim = victim;
        this.isValid = isValid;
        this.eventName = "player.checkmurder";
        this._alteredPlayer = player;
        this._alteredVictim = victim;
        this._alteredIsValid = isValid;
    }
    /**
     * The player that will murder the victim instead, if altered.
     */
    get alteredPlayer() {
        return this._alteredPlayer;
    }
    /**
     * Change the player that will actually murder the victim.
     */
    setPlayer(player) {
        this._alteredPlayer = player;
    }
    /**
     * The player that will murdered instead, if altered.
     */
    get alteredVictim() {
        return this._alteredVictim;
    }
    /**
     * Change the player that will actually be murdered.
     * @param victim The player to murder.
     */
    setVictim(victim) {
        this._alteredVictim = victim;
    }
    /**
     * Whether or not this murder will be considered valid instead, if altered.
     */
    get alteredIsValid() {
        return this._alteredIsValid;
    }
    /**
     * Change whether this murder should be consider valid. If valid, ths player
     * will indeed be murdered.
     * @param isValid Whether or not this murder should be considered valid.
     */
    setValid(isValid) {
        this._alteredIsValid = isValid;
    }
}
exports.PlayerCheckMurderEvent = PlayerCheckMurderEvent;
PlayerCheckMurderEvent.eventName = "player.checkmurder";
//# sourceMappingURL=CheckMurder.js.map