"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerSetPetEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player has their player pet updated.
 */
class PlayerSetPetEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The pet that the player had before.
     */
    oldPetId, 
    /**
     * The new pet that the player has.
     */
    newPetId) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.oldPetId = oldPetId;
        this.newPetId = newPetId;
        this.eventName = "player.setpet";
        this._alteredPetId = newPetId;
    }
    /**
     * The altered pet that the player will have set instead, if changed.
     */
    get alteredPetId() {
        return this._alteredPetId;
    }
    /**
     * Revert the player's pet back to their old pet.
     */
    revert() {
        this.setPet(this.oldPetId);
    }
    /**
     * Change the pet that the player had set.
     * @param pet The pet to set.
     */
    setPet(pet) {
        this._alteredPetId = pet;
    }
}
exports.PlayerSetPetEvent = PlayerSetPetEvent;
PlayerSetPetEvent.eventName = "player.setpet";
//# sourceMappingURL=SetPet.js.map