import { RevertableEvent } from "@skeldjs/events";
import { ProtectPlayerMessage } from "@skeldjs/protocol";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerEvent } from "./PlayerEvent";
/**
 * Emitted when a player (who is a shapeshifter) shapeshifts into another player.
 */
export declare class PlayerShapeshiftEvent<RoomType extends Hostable = Hostable> extends RevertableEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: ProtectPlayerMessage | undefined;
    /**
     * The target that the player shapeshifted into.
     */
    readonly target: PlayerData<RoomType>;
    /**
     * The duration, in seconds, for how long the player is shapeshifted for.
     */
    readonly duration: number;
    /**
     * Whether or not to show an animation of the player shapeshifting.
     */
    readonly doAnimation: boolean;
    static eventName: "player.shapeshift";
    eventName: "player.shapeshift";
    private _alteredTarget;
    private _alteredDoAnimation;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: ProtectPlayerMessage | undefined, 
    /**
     * The target that the player shapeshifted into.
     */
    target: PlayerData<RoomType>, 
    /**
     * The duration, in seconds, for how long the player is shapeshifted for.
     */
    duration: number, 
    /**
     * Whether or not to show an animation of the player shapeshifting.
     */
    doAnimation: boolean);
    /**
     * The player that the player will shapeshift into instead, if altered.
     */
    get alteredTarget(): PlayerData<RoomType>;
    /**
     * Whether or not to show an animation of the player shapeshifting instead, if altered.
     */
    get alteredDoAnimation(): boolean;
    /**
     * Change the player that the player will shapeshift into.
     * @param target The player to shapeshift into instead.
     */
    setTarget(target: PlayerData<RoomType>): void;
    /**
     * Change whether or not an animation will show the player shapeshifting.
     * @param doAnimation Whether or not to do show an animation of the player shape shifting.
     */
    setDoAnimation(doAnimation: boolean): void;
}
//# sourceMappingURL=Shapeshift.d.ts.map